Live class

Reactive text / subtree — the JSX {expr} equivalent.

Automatically tracks any Signal read during the execution of builder and updates only this region when signals change.

DOM Representation

Mounts between sentinel comments <!-- bloom:live --> and <!-- /bloom:live --> rather than creating a wrapper element.

final count = signal(0);

BloomNode counterView() => Div(
  children: [
    Live(() => P(text: 'Current count: ${count.value}')),
    Button(
      text: 'Increment',
      onClick: (e) => count.value++,
    ),
  ],
);
Inheritance

Constructors

Live(BloomNode builder())
Creates a reactive boundary descriptor driven by builder.
const

Properties

builder BloomNode Function()
The reactive builder callback invoked to produce this boundary's subtree.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited