defaultStrategy property
The default hydration strategy applied when the placeholder element does not specify one.
Implementation
final HydrationStrategy defaultStrategy;
The default hydration strategy applied when the placeholder element does not specify one.
final HydrationStrategy defaultStrategy;