isFailed property
bool
get
isFailed
Whether hydration failed due to a builder or DOM exception.
Implementation
bool get isFailed => _status == IslandStatus.failed;
Whether hydration failed due to a builder or DOM exception.
bool get isFailed => _status == IslandStatus.failed;