isPending property
bool
get
isPending
Whether this island is still awaiting its strategy trigger.
Implementation
bool get isPending => _status == IslandStatus.pending;
Whether this island is still awaiting its strategy trigger.
bool get isPending => _status == IslandStatus.pending;