unmount method
void
unmount()
Removes all child DOM elements from the host container and disposes all reactive effects.
Convenience alias for dispose.
Implementation
void unmount() => dispose();
Removes all child DOM elements from the host container and disposes all reactive effects.
Convenience alias for dispose.
void unmount() => dispose();