BloomVirtualItem constructor
Creates a BloomVirtualItem with the given index, start offset, and size.
Implementation
const BloomVirtualItem({required this.index, required this.start, required this.size});
Creates a BloomVirtualItem with the given index, start offset, and size.
const BloomVirtualItem({required this.index, required this.start, required this.size});