IslandStatus enum

Lifecycle status of an island instance managed by BloomIslandOrchestrator.

if (instance.status == IslandStatus.hydrated) {
  print('Island is interactive');
}
Inheritance
Available extensions

Values

pending → const IslandStatus

The island placeholder has been discovered but its hydration strategy trigger has not fired yet.

hydrated → const IslandStatus

The island has been successfully hydrated and is actively interactive.

failed → const IslandStatus

An error occurred during props extraction, builder execution, or DOM hydration.

disposed → const IslandStatus

The island instance has been unmounted and its resources have been released.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<IslandStatus>
A constant List of the values in this enum, in order of their declaration.