unregisterIsland function

bool unregisterIsland(
  1. String name
)

Removes an island definition by name from the global BloomIslandRegistry.instance.

Returns true if the island was registered and removed.

unregisterIsland('cart-badge');

Implementation

bool unregisterIsland(String name) =>
    BloomIslandRegistry.instance.unregister(name);