navigateQuery method
Navigates to an updated query string on the current pathname by pushing a new history entry.
Retains the current pathname and any existing hash fragment while updating query parameters.
Values in query are serialized with buildQueryString.
// Updates URL to '/current-path?page=3'
await controller.navigateQuery({'page': 3});
Implementation
Future<void> navigateQuery(Map<String, dynamic> query) async {
await setQuery(query, replace: false);
}